# Overview

This repo contains control code for Mini DenCam, a polar bear maternal
den observation device.  The project is a collaboration between the
Conservation Technology Lab at the San Diego Zoo Wildlife Alliance and
Polar Bears International.

# Hardware

The target hardware is a Raspberry Pi 4 Model B single board computer
with a Picamera-style camera and the AdaFruit PiTFT screen (2.8"
resistive touch model with 4 GPIO-connected buttons)
attached. Typically several storage devices are connected via the USB
ports on the Pi (e.g. uSD card readers). This hardware is typically
integrated into a larger assembly that includes a weatherproof
enclosure, batteries, charger controller, and an external solar
panels.

